﻿    using System;
    using ArtOfTest.WebAii.Core;
    using ArtOfTest.WebAii.Wpf;

namespace TestModalDialog
{

        public static class AppWrap
        {

            public static WpfApplication Application { get; private set; }
            public static MainWindow MainWindow { get; private set; }
            public static Manager Manager { get; private set; }
            public const string MainWindowCaption = "~MainWindow";

            /// <summary>
            ///     Stops this instance.
            /// </summary>
            public static void Close()
            {
                if (Application != null &&
                    Manager != null)
                {
                    Application.Quit();
                    Manager.Dispose();
                    Application = null;
                    Manager = null;
                }
            }

            /// <summary>
            ///     Starts the test runner.
            /// </summary>
            public static void Start(string exePath, string logPath)
            {
                string path = System.IO.Path.GetFullPath(exePath);
                StartUpManager(path, logPath);
              
                Application = Manager.LaunchNewApplication(Manager.Settings.Wpf.DefaultApplicationPath);
                Application.NewWindow += Application_NewWindow;
                ConnectToMainWindow(MainWindowCaption.ToUpperInvariant());
            }

            static void Application_NewWindow(object sender, ArtOfTest.Common.GenericEventArgs<WpfWindow> e)
            {
                // This gets called just once?
                Console.WriteLine("Create: " + e.Value.Window.GetWindowText());
            }


            private static void ConnectToMainWindow(string windowName)
            {
                var window = Application.WaitForWindow(windowName, TimePeriod.TwoMinutes);
                MainWindow = new MainWindow(window);
            }

            private static void StartUpManager(string ExePath, string logPath)
            {
                var settings = new Settings
                {
                    ClientReadyTimeout = TimePeriod.OneMinute,
                    ExecuteCommandTimeout = TimePeriod.ThirtySeconds,
                    ExecutionDelay = TimePeriod.HalfASecond,
                    UnexpectedDialogAction = UnexpectedDialogAction.HandleAndFailTest,
                    LogLocation = logPath,
                    DisableDialogMonitoring = false, //[Missing <summary> documentation for "P:ArtOfTest.WebAii.Core.Settings.DisableDialogMonitoring"] wtf is it?
                    Wpf = new Settings.WpfSettings
                    {
                        DefaultApplicationPath = ExePath,
                    },
                    SimulatedMouseMoveSpeed = 0.5f
                };

                Manager = new Manager(settings);
                Manager.Start();
            }
        }

    }

